@@ -24,7 +24,9 @@ __all__ = (
     "HumanLoopStatusType",
     "ListHumanLoopsPaginatorName",
     "SortOrderType",
+    "AugmentedAIRuntimeServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -33,6 +35,7 @@ ContentClassifierType = Literal["FreeOfAdultContent", "FreeOfPersonallyIdentifia
 HumanLoopStatusType = Literal["Completed", "Failed", "InProgress", "Stopped", "Stopping"]
 ListHumanLoopsPaginatorName = Literal["list_human_loops"]
 SortOrderType = Literal["Ascending", "Descending"]
+AugmentedAIRuntimeServiceName = Literal["sagemaker-a2i-runtime"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -64,6 +67,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -186,6 +190,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -334,4 +339,16 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_human_loops"]
