@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence, Union
 
+from typing_extensions import NotRequired
+
 from .literals import ContentClassifierType, HumanLoopStatusType, SortOrderType
 
 if sys.version_info >= (3, 9):
@@ -93,39 +95,25 @@ HumanLoopOutputTypeDef = TypedDict(
 HumanLoopSummaryTypeDef = TypedDict(
     "HumanLoopSummaryTypeDef",
     {
-        "HumanLoopName": str,
-        "HumanLoopStatus": HumanLoopStatusType,
-        "CreationTime": datetime,
-        "FailureReason": str,
-        "FlowDefinitionArn": str,
+        "HumanLoopName": NotRequired[str],
+        "HumanLoopStatus": NotRequired[HumanLoopStatusType],
+        "CreationTime": NotRequired[datetime],
+        "FailureReason": NotRequired[str],
+        "FlowDefinitionArn": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredListHumanLoopsRequestRequestTypeDef = TypedDict(
-    "_RequiredListHumanLoopsRequestRequestTypeDef",
+ListHumanLoopsRequestRequestTypeDef = TypedDict(
+    "ListHumanLoopsRequestRequestTypeDef",
     {
         "FlowDefinitionArn": str,
+        "CreationTimeAfter": NotRequired[Union[datetime, str]],
+        "CreationTimeBefore": NotRequired[Union[datetime, str]],
+        "SortOrder": NotRequired[SortOrderType],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
 )
-_OptionalListHumanLoopsRequestRequestTypeDef = TypedDict(
-    "_OptionalListHumanLoopsRequestRequestTypeDef",
-    {
-        "CreationTimeAfter": Union[datetime, str],
-        "CreationTimeBefore": Union[datetime, str],
-        "SortOrder": SortOrderType,
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-
-class ListHumanLoopsRequestRequestTypeDef(
-    _RequiredListHumanLoopsRequestRequestTypeDef, _OptionalListHumanLoopsRequestRequestTypeDef
-):
-    pass
-
 
 ListHumanLoopsResponseTypeDef = TypedDict(
     "ListHumanLoopsResponseTypeDef",
@@ -139,11 +127,10 @@ ListHumanLoopsResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -157,28 +144,15 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredStartHumanLoopRequestRequestTypeDef = TypedDict(
-    "_RequiredStartHumanLoopRequestRequestTypeDef",
+StartHumanLoopRequestRequestTypeDef = TypedDict(
+    "StartHumanLoopRequestRequestTypeDef",
     {
         "HumanLoopName": str,
         "FlowDefinitionArn": str,
         "HumanLoopInput": "HumanLoopInputTypeDef",
+        "DataAttributes": NotRequired["HumanLoopDataAttributesTypeDef"],
     },
 )
-_OptionalStartHumanLoopRequestRequestTypeDef = TypedDict(
-    "_OptionalStartHumanLoopRequestRequestTypeDef",
-    {
-        "DataAttributes": "HumanLoopDataAttributesTypeDef",
-    },
-    total=False,
-)
-
-
-class StartHumanLoopRequestRequestTypeDef(
-    _RequiredStartHumanLoopRequestRequestTypeDef, _OptionalStartHumanLoopRequestRequestTypeDef
-):
-    pass
-
 
 StartHumanLoopResponseTypeDef = TypedDict(
     "StartHumanLoopResponseTypeDef",
